@@ -24,10 +24,13 @@ def send_log_email():
     sender_email_configuration = SenderEmailConfiguration.objects.first()
     sender = sender_email_configuration.sender_email_address
 
-    email_configuration = EmailConfiguration.objects.values(
-        'SUBJECT',
-        'HTML_File',
-        'LOG_PATH').first()
+    email_configuration = EmailConfiguration.objects.values('Subject',
+                                                            'Logo',
+                                                            'Banner',
+                                                            'Log_path',
+                                                            'Email_Content',
+                                                            'HTML_File'
+                                                            ).first()
     # SUBJECT = email_configuration.SUBJECT
     # HTML_File = email_configuration.HTML_File
     # LOG_PATH = email_configuration.LOG_PATH
